pyzombie Start {0}

# pyzombie

## Start {0}

### Environment

#### Notes

- Each environment variable should occupy a single line and have the form `varkey = varvalue`.
- Whitespace before and after the key and value shall be stripped away.
- No variable expansion will occur on the values in this form.
- The initial text is the current environment that pyzombie server is using.

{1}

### Arguments

#### Notes

- Arguments may be on a single line or multiple lines.
- All whitespace will be colapsed into a single space.

{2}